var searchData=
[
  ['m_5fbitmap',['m_bitmap',['../classwxPLplotwindow.html#a448fc7b678fe9300e09a0ec4845aceb6',1,'wxPLplotwindow']]],
  ['m_5fboxold',['m_boxOld',['../classClipper.html#afd5c02f5915eedc7c585328f61da3276',1,'Clipper']]],
  ['m_5fbrush',['m_brush',['../classwxPLDevice.html#a4b7480eba456b5ae8b612f8dd46d11ee',1,'wxPLDevice::m_brush()'],['../classDrawingObjectsChanger.html#a5fbbe3d7c8277fc7a39a46d5227c0f70',1,'DrawingObjectsChanger::m_brush()']]],
  ['m_5fbuffer',['m_buffer',['../classPLMemoryMap.html#a40fe6923314fcefd4f239590eb91c470',1,'PLMemoryMap']]],
  ['m_5fcanvascolour',['m_canvasColour',['../classwxPLplotwindow.html#a56a3fc5e70ab0b4288d405eba3221103',1,'wxPLplotwindow']]],
  ['m_5fclipeverything',['m_clipEverything',['../classClipper.html#a1a095f85f1fcd4b3edb376b49524eb25',1,'Clipper']]],
  ['m_5fcompletedfirstrender',['m_completedFirstRender',['../classwxPLplotwindow.html#adaf0ac116110117160cf12032693bb92',1,'wxPLplotwindow']]],
  ['m_5fcreated',['m_created',['../classwxPLplotstream.html#abc3aab2b6b629049a6d0ac69ad6d7581',1,'wxPLplotstream::m_created()'],['../classwxPLplotwindow.html#ae146662e19866daab2746062529f6da6',1,'wxPLplotwindow::m_created()']]],
  ['m_5fdc',['m_dc',['../classwxPLDevice.html#afc1d2a710f600ff2880f37c54ea46e00',1,'wxPLDevice::m_dc()'],['../classScaler.html#a59bf721f4717c535c13889518b18efd6',1,'Scaler::m_dc()'],['../classOriginChanger.html#ad7c43a1f94266d8b434365df5d6807e1',1,'OriginChanger::m_dc()'],['../classDrawingObjectsChanger.html#a9f006e26b396936809f5b77453b44624',1,'DrawingObjectsChanger::m_dc()'],['../classTextObjectsSaver.html#adb0494be3b8ae1b2e1d085f4079ea58f',1,'TextObjectsSaver::m_dc()'],['../classClipper.html#aaf597ece37e08c7a615b29f52fb101ae',1,'Clipper::m_dc()']]],
  ['m_5fdheight',['m_dHeight',['../classQtPLDriver.html#a8331eefe652858a5d055faede0342117',1,'QtPLDriver']]],
  ['m_5fdwidth',['m_dWidth',['../classQtPLDriver.html#a65bfdf3be820ea5fe66aa4ba984f0ba4',1,'QtPLDriver']]],
  ['m_5ffci',['m_fci',['../classFont.html#adfc6270c470a16f2fac2faf95d15ed95',1,'Font']]],
  ['m_5ffixedaspect',['m_fixedAspect',['../classwxPLDevice.html#a2306ea3e694a2278f70e8d1f43a6f70d',1,'wxPLDevice']]],
  ['m_5ffont',['m_font',['../classFont.html#a2778e9d2b7c13fa88ad8c8127dd2a14c',1,'Font::m_font()'],['../classTextObjectsSaver.html#af0ba408c8d0a6f8637686f39f3cc891e',1,'TextObjectsSaver::m_font()']]],
  ['m_5ffontgrabber',['m_fontGrabber',['../classwxPLDevice.html#a38e7a85fd5e2e840d5297321b49f067f',1,'wxPLDevice']]],
  ['m_5fgc',['m_gc',['../classwxPLDevice.html#ab7ba43cf0ea08c6a8f00f45317c9c1b9',1,'wxPLDevice']]],
  ['m_5fhasfont',['m_hasFont',['../classFont.html#a4299d6eea9454f18638e20ec41f89cf3',1,'Font']]],
  ['m_5fhavelock',['m_haveLock',['../classPLNamedMutex.html#afefc1fce11d4ef31cc52428b64ed6a2d',1,'PLNamedMutex']]],
  ['m_5fheight',['m_height',['../classwxPLDevice.html#aeed53943f8c1559f56c8245cdae5ad4c',1,'wxPLDevice::m_height()'],['../classwxPLplotstream.html#aaea160e3e339333e4cc6a520f3ad8058',1,'wxPLplotstream::m_height()']]],
  ['m_5finitialsize',['m_initialSize',['../classwxPLplotwindow.html#a0c105bec0e7cdf1c4431b3c9eb2c4e3c',1,'wxPLplotwindow']]],
  ['m_5finteractivetextgcdc',['m_interactiveTextGcdc',['../classwxPLDevice.html#ae4bffb81489b74f0b6e7e8d64f5078f8',1,'wxPLDevice']]],
  ['m_5finteractivetextimage',['m_interactiveTextImage',['../classwxPLDevice.html#a1218ce165c8300691403cee09e5485e0',1,'wxPLDevice']]],
  ['m_5flastwascached',['m_lastWasCached',['../classFontGrabber.html#a14c5826cfb88218cdf4a6e25a7846552',1,'FontGrabber']]],
  ['m_5flinespacing',['m_lineSpacing',['../classwxPLDevice.html#a5f2d941853601f6c276e979d3cfd237a',1,'wxPLDevice']]],
  ['m_5flocalbufferposition',['m_localBufferPosition',['../classwxPLDevice.html#a8ad3a397168ffe6f2e35c0352fffc2d5',1,'wxPLDevice']]],
  ['m_5fmapfile',['m_mapFile',['../classPLMemoryMap.html#a3192f5b18352933c5e11d59a6fa9c06b',1,'PLMemoryMap']]],
  ['m_5fmax_5fstring_5flength',['m_max_string_length',['../classwxPLDevice.html#a1c7e40a21043e7248ebc6efab5a8ea2e',1,'wxPLDevice']]],
  ['m_5fmemorydc',['m_memoryDc',['../classwxPLplotwindow.html#a431044cf4a70a2aa3802a7ca585590f7',1,'wxPLplotwindow']]],
  ['m_5fmfo',['m_mfo',['../classwxPLDevice.html#a1a6111863fe30260fe178983e6933b94',1,'wxPLDevice']]],
  ['m_5fmutex',['m_mutex',['../classwxPLDevice.html#aee5f7baee0b93f262b723613eaeb9d24',1,'wxPLDevice::m_mutex()'],['../classPLNamedMutex.html#a467806679e3a35475e31c2f828c62bc0',1,'PLNamedMutex::m_mutex()'],['../classPLNamedMutexLocker.html#ac46a88ccd73cb2e568e912c1556a8ee5',1,'PLNamedMutexLocker::m_mutex()']]],
  ['m_5fmutexname',['m_mutexName',['../classPLNamedMutex.html#abf8be64f70cba1bdf01dbe7fa2e1b085',1,'PLNamedMutex']]],
  ['m_5fname',['m_name',['../classPLMemoryMap.html#a4eba8cab02237021c0fffa366a25032c',1,'PLMemoryMap']]],
  ['m_5foutputmemorymap',['m_outputMemoryMap',['../classwxPLDevice.html#a5733188555ab4b717a512acdd5747e57',1,'wxPLDevice']]],
  ['m_5fpainterp',['m_painterP',['../classQtPLDriver.html#a02e19738983645f3ef004afdaa5c7982',1,'QtPLDriver']]],
  ['m_5fpen',['m_pen',['../classwxPLDevice.html#a0079d66c3f5542e7a79624e12ce8e71c',1,'wxPLDevice::m_pen()'],['../classDrawingObjectsChanger.html#a10de9b95dfd82415875c19b2d913dc28',1,'DrawingObjectsChanger::m_pen()']]],
  ['m_5fplplotedgelength',['m_plplotEdgeLength',['../classwxPLDevice.html#ac572a6abcda3170a22d23452c7e1fca2',1,'wxPLDevice']]],
  ['m_5fprevbasefontsize',['m_prevBaseFontSize',['../classPlDevice.html#a0b267ae488f40583873569a89e93d52e',1,'PlDevice']]],
  ['m_5fprevfci',['m_prevFci',['../classPlDevice.html#a6f19415b240eb3cea734ac0872a812db',1,'PlDevice']]],
  ['m_5fprevfont',['m_prevFont',['../classFontGrabber.html#a925aff32d4a57e7e3e197d048be74949',1,'FontGrabber']]],
  ['m_5fprevlevel',['m_prevLevel',['../classPlDevice.html#ab7cf888f913ded8fbf11cf91174dffac',1,'PlDevice']]],
  ['m_5fprevsymbol',['m_prevSymbol',['../classPlDevice.html#a0d2c637ad0172db91550e0cedd186da7',1,'PlDevice']]],
  ['m_5fprevsymboldepth',['m_prevSymbolDepth',['../classPlDevice.html#a48c0b2f17fca05d1044d2a05ffa08191',1,'PlDevice']]],
  ['m_5fprevsymbolheight',['m_prevSymbolHeight',['../classPlDevice.html#a6b53b14849e41acc9d14fd64326913d9',1,'PlDevice']]],
  ['m_5fprevsymbolwidth',['m_prevSymbolWidth',['../classPlDevice.html#ae23d9a79a0d29fdcfb6cc3e4006203ed',1,'PlDevice']]],
  ['m_5frendertimer',['m_renderTimer',['../classwxPLplotwindow.html#a0a0311aad5868724e2e2bb354f6a530a',1,'wxPLplotwindow']]],
  ['m_5fresizerenderdelay',['m_resizeRenderDelay',['../classwxPLplotwindow.html#ab4ccae324d7f297aba5c4c7e0631cd2c',1,'wxPLplotwindow']]],
  ['m_5fresizing',['m_resizing',['../classwxPLplotwindow.html#a0aae6eeecc957a6a44b35e3dd6a40b61',1,'wxPLplotwindow']]],
  ['m_5fsaver',['m_saver',['../classTextObjectsChanger.html#ac69ea29fe1df7b53b55704db0e772209',1,'TextObjectsChanger']]],
  ['m_5fscale',['m_scale',['../classwxPLDevice.html#a50279c0d07a7533de040944191d18e95',1,'wxPLDevice']]],
  ['m_5fseed',['m_seed',['../classRand.html#ac0f529d022a39fbfaf5cd6c8a7c6b41b',1,'Rand']]],
  ['m_5fsize',['m_size',['../classFont.html#a74ccd496be9aceceb531cdef46696579',1,'Font::m_size()'],['../classPLMemoryMap.html#a3fb16c6e2101b9756e56c9b26b44195a',1,'PLMemoryMap::m_size()']]],
  ['m_5fstream',['m_stream',['../classwxPLplotwindow.html#a4a24892a8539fcbe23dfa2f22c886798',1,'wxPLplotwindow']]],
  ['m_5fstyle',['m_style',['../classwxPLplotstream.html#a3df90426558ef85eadbfd7439db533c0',1,'wxPLplotstream']]],
  ['m_5ftextbackground',['m_textBackground',['../classTextObjectsSaver.html#ae41d02f628e476a270f212c6b1b20240',1,'TextObjectsSaver']]],
  ['m_5ftextforeground',['m_textForeground',['../classTextObjectsSaver.html#a8702e29a376f2d815de8bddb697533f3',1,'TextObjectsSaver']]],
  ['m_5funderlined',['m_underlined',['../classFont.html#a68dd1b63e9ac17ca6e4699b492de189e',1,'Font']]],
  ['m_5fusedctexttransform',['m_useDcTextTransform',['../classwxPLDevice.html#a096e5f08aa45dd8ea7fc4b71f41b69d1',1,'wxPLDevice']]],
  ['m_5fusegraphicscontext',['m_useGraphicsContext',['../classwxPLplotwindow.html#af4600d45758ea7ade4dda619782431be',1,'wxPLplotwindow']]],
  ['m_5fwidth',['m_width',['../classwxPLDevice.html#a39aa02b295b77d9afe40b159405f13d8',1,'wxPLDevice::m_width()'],['../classwxPLplotstream.html#a372fffe187d3338a689829a34156f376',1,'wxPLplotstream::m_width()']]],
  ['m_5fxaspect',['m_xAspect',['../classwxPLDevice.html#ab18473f2c4fa0f288553bebeacc8658d',1,'wxPLDevice']]],
  ['m_5fxoriginold',['m_xOriginOld',['../classOriginChanger.html#a0fae758dbd539a17bcaab13a2c4801b3',1,'OriginChanger']]],
  ['m_5fxscale',['m_xScale',['../classwxPLDevice.html#ac4149fda5798c47e92d1b776ed79dda3',1,'wxPLDevice']]],
  ['m_5fxscaleold',['m_xScaleOld',['../classScaler.html#a1e60600170c92a4669e533276c478e40',1,'Scaler']]],
  ['m_5fyaspect',['m_yAspect',['../classwxPLDevice.html#ac5877deb7cfa29833eaca2e85ca11e9f',1,'wxPLDevice']]],
  ['m_5fyoriginold',['m_yOriginOld',['../classOriginChanger.html#a78bfce06a7967fe23fd9144c22a57c58',1,'OriginChanger']]],
  ['m_5fyscale',['m_yScale',['../classwxPLDevice.html#a02e7a573c63488a6b0fe4f984a6b9cb7',1,'wxPLDevice']]],
  ['m_5fyscaleold',['m_yScaleOld',['../classScaler.html#a2b833d6ba6585e0902a8a85c19fdf830',1,'Scaler']]],
  ['mag_5fcolor',['MAG_COLOR',['../namespaceplplot.html#ac50f05d8a58f2960cfe2a496d11fcad0',1,'plplot::MAG_COLOR()'],['../namespaceplplotc.html#aa4b8fceedde05716ae6f5ac30c62a173',1,'plplotc.MAG_COLOR()']]],
  ['majdef',['majdef',['../structPLStream.html#aacf7dc5832d875092cda05b39b5bab87',1,'PLStream']]],
  ['majht',['majht',['../structPLStream.html#aa2981115099d54a0bde1385b2f924ba1',1,'PLStream']]],
  ['map',['map',['../structTkwDisplay.html#a38447f7530a2bd88c44a66c8648640bb',1,'TkwDisplay::map()'],['../structXwDisplay.html#a33de88b20022123ff48d63d9140485e1',1,'XwDisplay::map()']]],
  ['mapform_5ffuncstr',['mapform_funcstr',['../plplotluacLUA__wrap_8c.html#a94a9dec6cb94efe1b6781d5151c6c983',1,'plplotluacLUA_wrap.c']]],
  ['mar',['mar',['../structPLStream.html#ab8ac2cfcc7c89b3cb21006ec7090a73b',1,'PLStream']]],
  ['mark',['mark',['../structline.html#aaf91bfecefdf672464ae2770354b513d',1,'line::mark()'],['../structPLStream.html#a79ee5c5d824a379d4f425f2b0f59b0ce',1,'PLStream::mark()']]],
  ['markerspec',['markerspec',['../structcdImageStruct.html#a6b020d74fb7617afe9af0660ce2759e4',1,'cdImageStruct']]],
  ['masterdevice',['masterDevice',['../classMasterHandler.html#a06e1664ac4084b34591d0dff946ed0ee',1,'MasterHandler']]],
  ['mastereh',['MasterEH',['../structTkwDev.html#a6e08c1095b1eaf5238fd8783661895f2',1,'TkwDev::MasterEH()'],['../structXwDev.html#a0698157daaf9b720ff0d554f8fb01a74',1,'XwDev::MasterEH()']]],
  ['mattable',['matTable',['../tclMatrix_8c.html#aae555c4f130e4b591c66a9096535a0ac',1,'tclMatrix.c']]],
  ['mattable_5finitted',['matTable_initted',['../tclMatrix_8c.html#a19fee3476426a6ec5696b2a040ec1b95',1,'tclMatrix.c']]],
  ['max',['max',['../classRand.html#a7e0ea4d6900b3bc0105018b3089494a0',1,'Rand']]],
  ['max_5finstr',['max_instr',['../structTkDev.html#a2e4c1b803e76c785b11ab83f0885d805',1,'TkDev::max_instr()'],['../structTkwDev.html#a80b01a0e2519a031b79e2086800ab1ff',1,'TkwDev::max_instr()'],['../structXwDev.html#ac7792e628a37239247220c22f83b92de',1,'XwDev::max_instr()']]],
  ['max_5fplflt_5falpha',['MAX_PLFLT_ALPHA',['../namespaceplplotc.html#ab1474f8948e23e422d68cd731209db54',1,'plplotc']]],
  ['max_5fplflt_5fcmap1',['MAX_PLFLT_CMAP1',['../namespaceplplotc.html#abf0513fac36de7636ff20d4cb0ac0ad1',1,'plplotc']]],
  ['max_5fplint_5frgb',['MAX_PLINT_RGB',['../namespaceplplotc.html#a7edcf604ac107cbe8020d348e344b7cd',1,'plplotc']]],
  ['max_5fpoints',['max_points',['../plshade_8c.html#a77efcd267dd75021a2e449bed4f91a48',1,'plshade.c']]],
  ['max_5fpts',['max_pts',['../plshade_8c.html#aa4cb4bf8bca0b78023e5c431e2197019',1,'plshade.c']]],
  ['maxlen',['maxlen',['../namespaceplplot.html#a0771bb612935378464fba135a16618b8',1,'plplot']]],
  ['maxwindows',['maxWindows',['../aqt_8c.html#add35f59d1173233ffee14c9fa4b97b09',1,'aqt.c']]],
  ['mcolor',['mcolor',['../structcdImageStruct.html#a02d35327105bdc1290111c2a7366888b',1,'cdImageStruct']]],
  ['member',['member',['../structPLStream.html#a47c3d2d47d3c0b105beb0981c5634d15',1,'PLStream']]],
  ['members',['members',['../structswig__octave__class.html#a0edef1ae878ed2e5b8bf9b4786b20f50',1,'swig_octave_class::members()'],['../classoctave__swig__type.html#a4d82069a306cab732e161b58c1d2919f',1,'octave_swig_type::members()']]],
  ['mesh',['MESH',['../namespaceplplot.html#a0a7a72416f1a62cbc7d6ed176f0889a0',1,'plplot::MESH()'],['../namespaceplplotc.html#a0165fba5e5a5eee4b396d9878b7e8850',1,'plplotc.MESH()']]],
  ['metafile_5fformat',['metafile_format',['../plmetafile_8c.html#a1763b8861c8032fdd2606dc6fd8685d4',1,'plmetafile.c']]],
  ['metatable',['metatable',['../structswig__lua__class.html#a7c56e45895444992b6a42c60ba6a17e5',1,'swig_lua_class']]],
  ['method',['method',['../structswig__octave__member.html#a92f709e4fb4bb8a48198939f2e2c549b',1,'swig_octave_member']]],
  ['methods',['methods',['../structswig__lua__class.html#ae0d9f30a8114623b1185b5907fc60719',1,'swig_lua_class']]],
  ['mf_5finfile',['mf_infile',['../structPLStream.html#a8697ddd687cd34315ba3765b196a778d',1,'PLStream']]],
  ['mf_5foutfile',['mf_outfile',['../structPLStream.html#afbc50e220f997c43679386a043a25ec2',1,'PLStream']]],
  ['mfpcxa',['mfpcxa',['../structPLmDev.html#a50c111e0be64b8759f57c693c099ebb9',1,'PLmDev']]],
  ['mfpcxb',['mfpcxb',['../structPLmDev.html#a8b050d4287d89d73529e8d8ee8a8feb7',1,'PLmDev']]],
  ['mfpcya',['mfpcya',['../structPLmDev.html#a71e0d2a614134a99588b8e3b05e2f6c2',1,'PLmDev']]],
  ['mfpcyb',['mfpcyb',['../structPLmDev.html#acbc0c3abc51a20a658fd6d025fb4f65b',1,'PLmDev']]],
  ['mhi',['mhi',['../plot3d_8c.html#a38796a973adb2afe32e23664bb8cd944',1,'plot3d.c']]],
  ['middle',['middle',['../structtriangle.html#aecd8e3f1c9a8e096c78278db631809c0',1,'triangle']]],
  ['min_5fplflt_5falpha',['MIN_PLFLT_ALPHA',['../namespaceplplotc.html#a302d63286fbe2d8d2114ef17c2b35b19',1,'plplotc']]],
  ['min_5fplflt_5fcmap1',['MIN_PLFLT_CMAP1',['../namespaceplplotc.html#a9a6764fa4d9f4d66e04e1343ddfd14b4',1,'plplotc']]],
  ['min_5fplint_5frgb',['MIN_PLINT_RGB',['../namespaceplplotc.html#a9c70f052d8bf32897d4f95d702f96091',1,'plplotc']]],
  ['min_5fpoints',['min_points',['../plshade_8c.html#a3f20636148fdd94d52564127774875d7',1,'plshade.c']]],
  ['min_5fpts',['min_pts',['../plshade_8c.html#a8a55dd46645e4e0d89cdb940b926c7ba',1,'plshade.c']]],
  ['mindef',['mindef',['../structPLStream.html#a3877166126904e55715aebbcf84e6ed6',1,'PLStream']]],
  ['minht',['minht',['../structPLStream.html#ae7f22f1bf0f3acd6c4293c40bb8ac0a6',1,'PLStream']]],
  ['minmax',['minmax',['../structplf2ops__t.html#a064ee4239a9424c7dd391bd2204f1d39',1,'plf2ops_t']]],
  ['mjdtojd',['MJDtoJD',['../qsastime__extra_8c.html#a3dd692ef315d653adec07cf79bbafab4',1,'qsastime_extra.c']]],
  ['mlo',['mlo',['../plot3d_8c.html#ab5532b964e2d395548e895f4a6b7616e',1,'plot3d.c']]],
  ['mode',['mode',['../structplplot_1_1__N1.html#affdc3d642e8589ed9146f675c477e031',1,'plplot::_N1::mode()'],['../structPLOptionTable.html#a813692b51c558740a63d3903bb226470',1,'PLOptionTable::mode()']]],
  ['mode_5ffull',['mode_full',['../plargs_8c.html#a7668606b7a9cc5a4c776602b05aedead',1,'plargs.c']]],
  ['mode_5fnodash',['mode_nodash',['../plargs_8c.html#aaa323210954478ca22b7ede410199df9',1,'plargs.c']]],
  ['mode_5fnodelete',['mode_nodelete',['../plargs_8c.html#a076cd4eede69b82f981a0c4a37cefca3',1,'plargs.c']]],
  ['mode_5fnoprogram',['mode_noprogram',['../plargs_8c.html#a6ef6bc558eb755a55ef1a6526bf416ec',1,'plargs.c']]],
  ['mode_5fquiet',['mode_quiet',['../plargs_8c.html#a989d16b7e7ed473e17ff9ae17de64ba9',1,'plargs.c']]],
  ['mode_5fshowall',['mode_showall',['../plargs_8c.html#a984cd53e5bebebb7780ea524b3ed5c96',1,'plargs.c']]],
  ['mode_5fskip',['mode_skip',['../plargs_8c.html#a1d0f9f7b3523a9887bb45efc35c22f80',1,'plargs.c']]],
  ['module',['module',['../classoctave__swig__type.html#a3fb5c7dae23c63d90ac19427f71cffab',1,'octave_swig_type']]],
  ['monthstartdoy',['MonthStartDOY',['../qsastime_8c.html#a61ba644a11b69c8b8e50ddd2c5c0dec3',1,'qsastime.c']]],
  ['monthstartdoy_5fl',['MonthStartDOY_L',['../qsastime_8c.html#a261632b1db65240555d04ba249ef80f8',1,'qsastime.c']]],
  ['msize',['msize',['../structcdImageStruct.html#a83e5a11f1080b78f3f3b6ba75e5eaecb',1,'cdImageStruct']]],
  ['mt',['mt',['../mt19937ar_8c.html#aff3cefd0011b487c57a7af7cb3bc499f',1,'mt19937ar.c']]],
  ['mti',['mti',['../mt19937ar_8c.html#a0893639c022032e006e5b13378f7b4b2',1,'mt19937ar.c']]],
  ['mtype',['mtype',['../structcdImageStruct.html#ade89f12f41d1dbb93d77d8df2c4d1531',1,'cdImageStruct']]],
  ['mul',['mul',['../structplf2ops__t.html#aff1cc82f307de8d430f496c07a9143e7',1,'plf2ops_t']]],
  ['mutex',['mutex',['../classQtPLDriver.html#a970f4f57f9b1cf27d5d4c500298a5091',1,'QtPLDriver']]],
  ['myct_5ffuncstr',['myct_funcstr',['../plplotluacLUA__wrap_8c.html#aa5ede8a2565e24ed4df2e0896f47036c',1,'plplotluacLUA_wrap.c']]],
  ['myl',['myL',['../plplotluacLUA__wrap_8c.html#a9917af03e350a440311193fb9099c720',1,'plplotluacLUA_wrap.c']]],
  ['mylabel_5ffuncstr',['mylabel_funcstr',['../plplotluacLUA__wrap_8c.html#a5797cce2266cabb8bc8f22e3c212fb2c',1,'plplotluacLUA_wrap.c']]],
  ['mypltr_5ffuncstr',['mypltr_funcstr',['../plplotluacLUA__wrap_8c.html#a6abec419e8ef65ee5b90b45b293654ae',1,'plplotluacLUA_wrap.c']]]
];
